default_shortcuts = {
    'napari:toggle_console_visibility': ['Control-Shift-C'],
    'napari:reset_scroll_progress': ['Control'],
    'napari:toggle_ndisplay': ['Control-Y'],
    'napari:toggle_theme': ['Control-Shift-T'],
    'napari:reset_view': ['Control-R'],
    'napari:increment_dims_left': ['Left'],
    'napari:increment_dims_right': ['Right'],
    'napari:focus_axes_up': ['Alt-Up'],
    'napari:focus_axes_down': ['Alt-Down'],
    'napari:roll_axes': ['Control-E'],
    'napari:transpose_axes': ['Control-T'],
    'napari:remove_selected': ['Control-Backspace', 'Control-Delete'],
    'napari:select_all': ['Control-A'],
    'napari:remove_all_layers': [
        'Control-Shift-Backspace',
        'Control-Shift-Delete',
    ],
    'napari:select_layer_above': ['Up'],
    'napari:select_layer_below': ['Down'],
    'napari:also_select_layer_above': ['Shift-Up'],
    'napari:also_select_layer_below': ['Shift-Down'],
    'napari:toggle_grid': ['Control-G'],
    'napari:toggle_selected_visibility': ['V'],
}
